#
# spec file for package dejagnu
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           dejagnu
BuildRequires:  automake
Requires:       expect
Requires:       tcl
Version:        1.4.4
Release:        5.100
Summary:        Framework for Running Test Suites on Software Tools
License:        GPL-2.0+
Group:          Development/Tools/Building
Url:            http://www.gnu.org/software/dejagnu/
Source:         http://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz
Source1:        site.exp
Patch0:         %{name}-make_doc.patch
Patch4:         dejagnu-ignore-libwarning.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
DejaGnu is a framework for testing other programs.  Its purpose is to
provide a single front-end for all tests.  Beyond this, DejaGnu offers
several advantages for testing:

1. The flexibility and consistency of the DejaGnu framework make it
   easy to write tests for any program.

1. DejaGnu provides a layer of abstraction that allows you to write
   tests that are portable to any host or target where a program
   must be tested.  For instance, a test for GDB can run (from any
   Unix-based host) on any target architecture that DejaGnu
   supports.

1. All tests have the same output format.  This makes it easy to
   integrate testing into other software development processes.
   DejaGnu's output is designed to be parsed by other filtering
   scripts and it is also human-readable.

DejaGnu is written in expect, which in turn uses "Tcl"--Tool command
language.

Running tests requires two things: the testing framework and the test
suites themselves.

%prep
%setup -q -n %{name}-%{version}
%patch0
%patch4 -p1
# argh, auto* requires this file
touch example/calc/ChangeLog

%build
autoreconf -f -i
%configure --verbose
make %{?_smp_mflags}
#cd doc
#makeinfo dejagnu.texi

%install
make install DESTDIR=$RPM_BUILD_ROOT
#install -d $RPM_BUILD_ROOT%{_defaultdocdir}/dejagnu
install -d $RPM_BUILD_ROOT%{_sysconfdir}/dejagnu
#install -d $RPM_BUILD_ROOT%{_datadir}/dejagnu
install %{S:1} $RPM_BUILD_ROOT%{_sysconfdir}/dejagnu/site.exp
ln -s -f %{_sysconfdir}/dejagnu/site.exp $RPM_BUILD_ROOT%{_datadir}/dejagnu/site.exp
#
# install doc
make install-doc \
    DESTDIR=$RPM_BUILD_ROOT \
    mandir=%{_mandir} \
    pkgdatadir=%{_docdir}/dejagnu \
    install-doc
# we currently don't want some doc...
rm -f $RPM_BUILD_ROOT%{_defaultdocdir}/dejagnu/{dejagnu.ps,dejagnu.rtf}
# add some text files
install -m 644 ChangeLog COPYING NEWS README AUTHORS TODO $RPM_BUILD_ROOT%{_defaultdocdir}/dejagnu/
# install examples
install -m 755 -d $RPM_BUILD_ROOT%{_defaultdocdir}/dejagnu/example
# examples
for exmp in calc hello ; do
    cp -r example/$exmp $RPM_BUILD_ROOT%{_defaultdocdir}/dejagnu/example/
    pushd $RPM_BUILD_ROOT%{_defaultdocdir}/dejagnu/example/$exmp;
        autoreconf -fi
        make distclean
        rm -rf *~ autom4te.cache
    popd
done
# info pages
#mkdir -p $RPM_BUILD_ROOT/%{_infodir}
#install -m 644 doc/dejagnu.info* $RPM_BUILD_ROOT/%{_infodir}

%files
%defattr(-, root, root)
%doc %{_defaultdocdir}/dejagnu
%dir %{_datadir}/dejagnu
%dir %{_sysconfdir}/dejagnu
/usr/bin/runtest
%doc %{_mandir}/man1/*
/usr/include/*
#%doc %{_infodir}/*
%config(noreplace) %{_sysconfdir}/dejagnu/site.exp
%{_datadir}/dejagnu/*

%changelog
* Fri Mar 22 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Fri Jan 11 2013 coolo@suse.com
- remove suse_update_config macro
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Mon Dec  7 2009 jengelh@medozas.de
- enable parallel building
* Wed May 16 2007 rguenther@suse.de
- Remove files from correct place.
* Sun Feb 11 2007 aj@suse.de
- Fix install of manpage.
* Wed Jun 14 2006 mmarek@suse.cz
- remove more backup files (autoreconf leftovers)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jul 26 2004 schwab@suse.de
- Rerun autoreconf in example directories.
* Mon May 31 2004 mcihar@suse.cz
- update to 1.4.4
* Thu Mar 18 2004 mcihar@suse.cz
- remove backup files
* Wed Oct  1 2003 kukuk@suse.de
- Don't regenerate documentation
* Thu Aug 14 2003 mcihar@suse.cz
- included examples (bug #28172)
* Mon Jun  9 2003 aj@suse.de
-  Ignore linker warning when searching 64bit libraries in /lib.
* Tue May 20 2003 aj@suse.de
- Fix wrong break statement so that correct runtest.exp is taken.
* Mon May 19 2003 aj@suse.de
- Fix handling of [getdirs -all $rootdir].
* Tue May 13 2003 aj@suse.de
- Handle _exit correctly.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <jade_dsl> to <openjade>
- changed neededforbuild <sp> to <opensp>
* Fri Nov  8 2002 mcihar@suse.cz
- included /usr/include/dejagnu.h in rpm
* Wed Sep 25 2002 mcihar@suse.cz
- new upstream version 1.4.3, major changes:
  1. New XML output option, so test results can be loaded into a
  database.
  2. Support for the KFAIL/KPASS (known failures). This is
  mostly oriented towards GDB testing.
  3. New "Hello World" example.
  4. New tutorial chapter.
- removed uneeded patches
- config site.exp is now physically located in /etc/dejagnu, in
  /usr/share/dejagnu is just symlink
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Sep  2 2002 kukuk@suse.de
- Remove sh-utils from neededforbuild
* Fri Jul 12 2002 aj@suse.de
- Fix remote.exp.
- Add support for mmixware simulator.
* Wed Jun 26 2002 schwab@suse.de
- Fix argument parsing.
* Tue Jun 25 2002 schwab@suse.de
- Restore working site.exp.
* Fri Jun 14 2002 mcihar@suse.cz
- updated to 1.4.2:
  * Various patches for bugs reported from net users.
  * There is new support for a simple unit testing API, that is
  also useful for embedded testing.
- html and pdf documantaion is included
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Wed Apr 18 2001 nadvornik@suse.cz
- installed info pages [bug #6990]
* Thu Mar 15 2001 nadvornik@suse.cz
- update to 1.4.0
* Wed Apr 19 2000 nadvornik@suse.cz
- added BuildRoot
- added URL
- fixed Group tag
* Mon Mar  6 2000 ro@suse.de
- use macro for mandir
* Tue Nov 30 1999 kukuk@suse.de
- Fix SIGPWR/SIGLOST for SPARC
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Jun 30 1999 ro@suse.de
- update to snapshot 19990614
* Mon Oct 20 1997 hf@suse.de
  ready for autobuild
* Mon Apr 28 1997 hf@suse.de
  New version of dejagnu works with tcl7.6 and expect 5.22,
  and have more procs.
